---
title: PICS
---

**PICS Overview:**

PICS is a fine-mapping method designed to identify the most likely causal SNPs associated with a trait or disease within a genomic region. It leverages both haplotype information and the observed association patterns from genome-wide association studies (GWAS).

Please refer to the original publication for in-depth details: [PICS Publication](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC4336207/).

We use PICS for both GWAS clumping results and GWAS curated studies.

:::gentropy.method.pics.PICS
